pub struct LaneDiagnosticsSnapshot { /* private fields */ }Expand description
One immutable structural snapshot used to evaluate Plan placement.
Implementations
Sourceimpl LaneDiagnosticsSnapshot
impl LaneDiagnosticsSnapshot
Sourcepub fn lane_cpu_time(&self) -> &BTreeMap<String, Duration>
pub fn lane_cpu_time(&self) -> &BTreeMap<String, Duration>
Returns CPU time consumed by each lane’s owner thread.
Sourcepub fn instance_queue_depth(&self, instance: &str) -> Option<usize>
pub fn instance_queue_depth(&self, instance: &str) -> Option<usize>
Returns the latest bounded request queue depth for one Plugin Instance.
Sourcepub const fn total_messages(&self) -> u64
pub const fn total_messages(&self) -> u64
Returns the number of observed App request messages.
Sourcepub const fn cross_lane_messages(&self) -> u64
pub const fn cross_lane_messages(&self) -> u64
Returns the number of observed messages whose binding crosses lanes.
Returns the share of observed request messages whose binding crosses lanes.